RuStoreMiniAppController class
Methods
-
clearPersistentData({bool forceReBuild = false, bool forceClearLocalStorage = false, String? builderName})
→ Future
-
forceReBuild if true, it will call rebuild() after
the data is cleared.
forceClearLocalStorage makes sense only if you set
preserveLocalStorageOnControllerDispose to true for your controller.
This flag will clear your local storage
inherited
-
delay(int millis)
→ Future
-
It's just a utility method in case you need to
simulate some loading or just wait for something
inherited
-
getIsLoading(String? loaderName)
→ bool
-
inherited
-
getPersistentList<TGenericType>(String key)
→ List<TGenericType>?
-
inherited
-
getPersistentValue<TType>(String key)
→ dynamic
-
Retrieves a persistent data stored in SharedPreferences
You can use your own types here but in this
case you need to add json encoders / revivers so that
jsonEncode / jsonDecode could understand how to work with your type
inherited
-
loadReferrerData([bool debug = false])
→ Future
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onLocalStorageInitialized()
→ void
-
called when the local storage has
loaded all stored values. Override it if you
need to get some values from local storage
override
-
rebuild([String? builderName])
→ void
-
builderName allows to build only a specific builder
for example, you have a view widgets wrapped in LiteState in the same page
if you pass a name to a lite state builder, you can then use it in this method
to rebuild a particular one. This might be very useful with complex UIs
inherited
-
reset()
→ void
-
override
-
setDebug(bool value)
→ void
-
-
setIsLoading(String? loaderName, bool value, {String? builderName})
→ void
-
inherited
-
setPersistentList<TGenericType>(String key, List<TGenericType> values)
→ Future
-
inherited
-
setPersistentValue<TType>(String key, TType? value, {bool mustRebuild = true, String? builderName})
→ Future
-
inherited
-
startLoading()
→ void
-
inherited
-
stopAllLoadings([List<String>? except])
→ void
-
just sets all loader flags to false
but doesn't actually stop any loaders
except if, for some reason you want to
keep some loaders running, just pass their names here
inherited
-
stopLoading()
→ void
-
inherited
-
toString()
→ String
-
A string representation of this object.
inherited