ReferrerData class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ReferrerData({bool? success, String? referrerId, String? error, String? packageName})
ReferrerData.fromJson(Map<String, dynamic> json)
factory

Properties

error String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
packageName String?
getter/setter pair
referrerId String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool?
getter/setter pair

Methods

encode() Map
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Map data) ReferrerData
deserialize(Map<String, dynamic> json) ReferrerData